<?php
	/**************************************************************************\
	* phpGroupWare - Messenger                                                 *
	* http://www.phpgroupware.org                                              *
	* This application written by Joseph Engo <jengo@phpgroupware.org>         *
	* --------------------------------------------                             *
	* Funding for this program was provided by http://www.checkwithmom.com     *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/

	/* $Id: index.php 18358 2007-11-27 04:43:37Z skwashd $ */
	$GLOBALS['phpgw_info'] = array();

	$GLOBALS['phpgw_info']['flags'] = array(
		'currentapp' => 'addressbook',
		'noheader'   => True,
		'nonavbar'   => True
	);
	include('../header.inc.php');
	
	$parms = Array(
		       'menuaction'=> 'addressbook.uiaddressbook.index',
		       'section' => 'Persons',
		       'cat_id' => phpgw::get_var('cat_id')
		       );

	$GLOBALS['phpgw']->redirect_link('/index.php',$parms);
?>
